@@ -154,7 +154,7 @@ class Formatter:
                                     not_, variable, condition_, value_
                                 )
                         if value:
-                            items.append("{}={}".format(key, value))
+                            items.append(f"{key}={value}")
                         else:
                             items.append(key)
 
@@ -179,8 +179,7 @@ class Formatter:
                 and token.group("key") in placeholder_formats
             ):
                 output.append(
-                    "{%s%s}"
-                    % (token.group("key"), placeholder_formats[token.group("key")])
+                    f"{{{token.group('key')}{placeholder_formats[token.group('key')]}}}"
                 )
                 continue
             value = token.group(0)
@@ -312,7 +311,7 @@ class Placeholder:
         """
         return the correct value for the placeholder
         """
-        value = "{%s}" % self.key
+        value = f"{{{self.key}}}"
         try:
             value = value_ = get_params(self.key)
             if self.format.startswith(":"):
@@ -326,20 +325,20 @@ class Placeholder:
                 # be successfully converted then the format will be removed.
                 try:
                     if "ceil" in self.format:
-                        value = int(ceil(float(value)))
+                        value = ceil(float(value))
                     if "f" in self.format:
                         value = float(value)
                     if "g" in self.format:
                         value = float(value)
                     if "d" in self.format:
                         value = int(float(value))
-                    output = "{{[{}]{}}}".format(self.key, self.format)
+                    output = f"{{[{self.key}]{self.format}}}"
                     value = output.format({self.key: value})
                     value_ = float(value)
                 except ValueError:
                     pass
             elif self.format.startswith("!"):
-                output = "{{{}{}}}".format(self.key, self.format)
+                output = f"{{{self.key}{self.format}}}"
                 value = value_ = output.format(**{self.key: value})
 
             if block.commands.not_zero:
@@ -357,14 +356,14 @@ class Placeholder:
         return valid, value, enough
 
     def __repr__(self):
-        return "<Placeholder {%s}>" % self.repr()
+        return f"<Placeholder {{{self.repr()}}}>"
 
     def repr(self):
         if self.format:
-            value = "{}{}".format(self.key, self.format)
+            value = f"{self.key}{self.format}"
         else:
             value = self.key
-        return "{%s}" % value
+        return f"{{{value}}}"
 
 
 class Literal:
@@ -376,7 +375,7 @@ class Literal:
         self.text = text
 
     def __repr__(self):
-        return "<Literal %s>" % self.text
+        return f"<Literal {self.text}>"
 
     def repr(self):
         return self.text
@@ -562,7 +561,7 @@ class Block:
         return self.next_block
 
     def __repr__(self):
-        return "<Block %s>" % self.repr()
+        return f"<Block {self.repr()}>"
 
     def repr(self):
         my_repr = [x.repr() for x in self.content]
@@ -624,8 +623,8 @@ class Block:
         # clean
         color = self.commands.color
         if color and color[0] != "#":
-            color_name = "color_%s" % color
-            threshold_color_name = "color_threshold_%s" % color
+            color_name = f"color_{color}"
+            threshold_color_name = f"color_threshold_{color}"
             # substitute color
             color = (
                 getattr(module, color_name, None)
@@ -667,8 +666,8 @@ class Block:
                 # if this is a block then likely it is soft.
                 if not out:
                     continue
-                for x in range(index + 1, len(output)):
-                    if output[x] and not isinstance(output[x], Block):
+                for other in output[index + 1 :]:
+                    if other and not isinstance(other, Block):
                         valid, _output = item.render(get_params, module, _if=True)
                         if _output and _output != last_block:
                             last_block = _output
