@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display time spent and calculate the price of your service.
 
@@ -39,12 +38,12 @@ SAMPLE OUTPUT
 """
 
 
-import os
 import time
+from pathlib import Path
 
 
 # No "magic numbers"
-SECS_IN_MIN = 60.0
+SECS_IN_MIN = 60
 SECS_IN_HOUR = 60 * SECS_IN_MIN  # 3600
 SECS_IN_DAY = 24 * SECS_IN_HOUR  # 86400
 
@@ -62,13 +61,13 @@ class Py3status:
     tax = 1.02
 
     def post_config_hook(self):
-        self.config_file = os.path.expanduser(self.config_file)
+        self.config_file = Path(self.config_file).expanduser()
         self.running = False
         self.saved_time = 0
         self.start_time = self.current_time
         try:
             # Use file to refer to the file object
-            with open(self.config_file) as file:
+            with self.config_file.open() as file:
                 self.saved_time = float(file.read())
         except:  # noqa e722 // (IOError, FileNotFoundError):  # py2/py3
             pass
@@ -77,9 +76,9 @@ class Py3status:
     def current_time(self):
         """Get the current time.
 
-        Using a helper property to make it easy to keep consitency.
+        Using a helper property to make it easy to keep consistency.
         """
-        return time.time()
+        return time.perf_counter()
 
     @staticmethod
     def secs_to_dhms(time_in_secs):
@@ -88,12 +87,9 @@ class Py3status:
         Using days as the largest unit of time.  Blindly using the days in
         `time.gmtime()` will fail if it's more than one month (days > 31).
         """
-        days = int(time_in_secs / SECS_IN_DAY)
-        remaining_secs = time_in_secs % SECS_IN_DAY
-        hours = int(remaining_secs / SECS_IN_HOUR)
-        remaining_secs = remaining_secs % SECS_IN_HOUR
-        mins = int(remaining_secs / SECS_IN_MIN)
-        secs = int(remaining_secs % SECS_IN_MIN)
+        days, secs = divmod(int(time_in_secs), SECS_IN_DAY)
+        hours, secs = divmod(secs, SECS_IN_HOUR)
+        mins, secs = divmod(secs, SECS_IN_MIN)
         return days, hours, mins, secs
 
     def _start_timer(self):
@@ -114,7 +110,7 @@ class Py3status:
 
     def kill(self):
         self._stop_timer()
-        with open(self.config_file, "w") as f:
+        with self.config_file.open("w") as f:
             f.write(str(self.saved_time))
 
     def on_click(self, event):
@@ -126,7 +122,7 @@ class Py3status:
     def _reset(self):
         if not self.running:
             self.saved_time = 0.0
-            with open(self.config_file, "w") as f:
+            with self.config_file.open("w") as f:
                 f.write("0")
 
     def rate_counter(self):
@@ -139,14 +135,14 @@ class Py3status:
             running_time = self.saved_time
 
         days, hours, mins, secs = self.secs_to_dhms(running_time)
-        subtotal = float(self.hour_price) * (running_time / SECS_IN_HOUR)
+        subtotal = self.hour_price * running_time / SECS_IN_HOUR
         total = subtotal * float(self.tax)
         subtotal_cost = self.py3.safe_format(
-            self.format_money, {"price": "%.2f" % subtotal}
+            self.format_money, {"price": f"{subtotal:.2f}"}
         )
-        total_cost = self.py3.safe_format(self.format_money, {"price": "%.2f" % total})
+        total_cost = self.py3.safe_format(self.format_money, {"price": f"{total:.2f}"})
         tax_cost = self.py3.safe_format(
-            self.format_money, {"price": "%.2f" % (total - subtotal)}
+            self.format_money, {"price": f"{total - subtotal:.2f}"}
         )
         response = {
             "cached_until": self.py3.time_in(self.cache_timeout),
